==> 0.0.37.tar.gz: lib/frontend_analyzer/frontend_analyzer.dart <==
library peg.frontend_analyzer.frontend_analyzer;

import 'package:lists/lists.dart';
import 'package:peg/automaton/automaton.dart';
import 'package:peg/grammar/expressions.dart';
import 'package:peg/grammar/grammar.dart';
import 'package:peg/grammar/production_rule.dart';
import 'package:peg/grammar/expression_visitors.dart';
import 'package:unicode/unicode.dart';

part 'src/frontend_analyzer/expected_lexemes_resolver.dart';
part 'src/frontend_analyzer/expression_able_not_consume_input_resolver.dart';
part 'src/frontend_analyzer/expression_callers_resolver.dart';
part 'src/frontend_analyzer/expression_length_resolver.dart';
part 'src/frontend_analyzer/expression_level_resolver.dart';
part 'src/frontend_analyzer/expression_matches_eof_resolver.dart';
part 'src/frontend_analyzer/expression_resolver.dart';
part 'src/frontend_analyzer/expression_hierarchy_resolver.dart';
part 'src/frontend_analyzer/expression_ownership_resolver.dart';
part 'src/frontend_analyzer/expression_with_actions_resolver.dart';
part 'src/frontend_analyzer/frontend_analyzer.dart';
part 'src/frontend_analyzer/invocations_resolver.dart';
part 'src/frontend_analyzer/left_expressions_resolver.dart';
part 'src/frontend_analyzer/optional_expressions_resolver.dart';
part 'src/frontend_analyzer/repetition_expressions_resolver .dart';
part 'src/frontend_analyzer/right_expressions_resolver.dart';
part 'src/frontend_analyzer/rule_expression_resolver.dart';
part 'src/frontend_analyzer/starting_rules_finder.dart';
part 'src/frontend_analyzer/start_characters_resolver.dart';
part 'src/frontend_analyzer/terminal_rules_finder.dart';

==> 0.0.51.tar.gz: lib/frontend_analyzer/frontend_analyzer.dart <==
library peg.frontend_analyzer.frontend_analyzer;

import 'package:lists/lists.dart';
import 'package:peg/grammar/expression_visitors.dart';
import 'package:peg/grammar/expressions.dart';
import 'package:peg/grammar/grammar.dart';
import 'package:peg/grammar/production_rule.dart';
import 'package:unicode/unicode.dart';

part 'src/frontend_analyzer/expected_lexemes_resolver.dart';
part 'src/frontend_analyzer/expression_able_not_consume_input_resolver.dart';
part 'src/frontend_analyzer/expression_callers_resolver.dart';
part 'src/frontend_analyzer/expression_hierarchy_resolver.dart';
part 'src/frontend_analyzer/expression_length_resolver.dart';
part 'src/frontend_analyzer/expression_level_resolver.dart';
part 'src/frontend_analyzer/expression_matches_eof_resolver.dart';
part 'src/frontend_analyzer/expression_ownership_resolver.dart';
part 'src/frontend_analyzer/expression_resolver.dart';
part 'src/frontend_analyzer/expression_with_actions_resolver.dart';
part 'src/frontend_analyzer/frontend_analyzer.dart';
part 'src/frontend_analyzer/invocations_resolver.dart';
part 'src/frontend_analyzer/left_expressions_resolver.dart';
part 'src/frontend_analyzer/optional_expressions_resolver.dart';
part 'src/frontend_analyzer/production_rule_kinds_resolver.dart';
part 'src/frontend_analyzer/repetition_expressions_resolver .dart';
part 'src/frontend_analyzer/right_expressions_resolver.dart';
part 'src/frontend_analyzer/rule_expression_resolver.dart';
part 'src/frontend_analyzer/start_characters_resolver.dart';
part 'src/frontend_analyzer/starting_rules_finder.dart';
